@@ -1,3 +1,5 @@
+import traceback
+
 import pandas as pd
 import pytest
 from .drivers.browsers import browser_os_name_conf
@@ -7,6 +9,45 @@ from datetime import datetime
 import os, pytest, sys, time
 
 
+@pytest.fixture
+def test_obj(base_url, browser, browser_version, os_version, os_name, remote_flag, testrail_flag, tesults_flag,
+             test_run_id, remote_project_name, remote_build_name, testname, reportportal_service, interactivemode_flag,
+             test_env, screenshot_option, xlsx_config, product):
+
+        test_obj.test_env = test_env
+        test_obj.screenshot = screenshot_option
+        test_obj.set_calling_module(testname)
+        test_obj.product = product
+        test_obj.browser = browser
+        test_obj.xlsx_config = xlsx_config
+        # Setup and register a driver
+        test_obj.register_driver(remote_flag, os_name, os_version, browser, browser_version, remote_project_name,
+                                 remote_build_name)
+
+        # Setup TestRail reporting
+        # if testrail_flag.lower() == 'y':
+        #     if test_run_id is None:
+        #         test_obj.write(
+        #             '\033[91m' + "\n\nTestRail Integration Exception: It looks like you are trying to use TestRail Integration without providing test run id. \nPlease provide a valid test run id along with test run command using -R flag and try again. for eg: pytest -X Y -R 100\n" + '\033[0m')
+        #         testrail_flag = 'N'
+        #     if test_run_id is not None:
+        #         test_obj.register_testrail()
+        #         test_obj.set_test_run_id(test_run_id)
+
+        if tesults_flag.lower() == 'y':
+            test_obj.register_tesults()
+
+        if reportportal_service:
+            test_obj.set_rp_logger(reportportal_service)
+        test_obj.start_time = int(time.time())
+
+        yield test_obj
+        # Teardown
+        test_obj.log_obj.remove_logger()  # Remove original log handlers
+        test_obj.wait(3)
+        test_obj.teardown()
+
+
 @pytest.fixture
 def testname(request):
     "pytest fixture for testname"
@@ -526,6 +567,7 @@ def reportportal_service(request):
 
     return reportportal_pytest_service
 
+
 @pytest.fixture
 def test_env(request):
     "pytest service fixture for set test environment"
@@ -539,4 +581,49 @@ def test_env(request):
 
     return test_env
 
+@pytest.fixture
+def xlsx_config(request):
+    "pytest service fixture for set test environment"
+    xlsx_config = None
+    try:
+        if request.config.getoption("--xlsx"):
+            xlsx_config = request.config.getoption("--xlsx")
+    except Exception as e:
+        print("Exception when trying to run test: %s" % __file__)
+        print("Python says:%s" % str(e))
+
+    return xlsx_config
+
+
+@pytest.fixture
+def screenshot_option(request):
+    """pytest service fixture for set enable or disable screenshot"""
+    setup = "off"
+    setting = request.config.getoption("--screenshot")
+    try:
+        if setting and setting.lower() == "all":
+            setup = "all"
+        elif setting and setting.lower() == "failonly":
+            setup = "failonly"
+        elif setting and setting.lower() == "off":
+            setup = "off"
+        elif setting:
+            raise ValueError(
+                "--screenshot option only allow all/failonly/off. Not allow %s. Set --screenshot off in this test" % setting)
+    except Exception as e:
+        print("Exception when trying to run test: %s" % __file__)
+        print("Python says:%s" % str(e))
+
+    return setup
+
+
+def configure_Base(config):
+    """Sets the launch name based on the marker selected."""
+    global if_reportportal
+    if_reportportal = config.getoption('--reportportal')
+
+    # Registering custom markers to supress warnings
+    config.addinivalue_line("markers", "GUI: mark a test as part of the GUI regression suite.")
+    config.addinivalue_line("markers", "API: mark a test as part of the GUI regression suite.")
+    config.addinivalue_line("markers", "MOBILE: mark a test as part of the GUI regression suite.")
 
